==> dde-session-shell_5.5.69.orig.tar.xz: dde-session-shell-5.5.69/translations/dde-session-shell_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Face İD-nizi doğrulayın</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face İD kilidləndi, lütfən şifrədən istifadə edin</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Barmaq izinizi doğrulayın</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Barmaq izi kilidləndi, şifrədən istifadə edin</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Iris ID-nizi doğrulayın</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>İris İD kilidləndi, lütfən şifrədən istifadə edin</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Şifrə</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfən, 1 dəqiqə sonra cəhd edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Şifrəni sıfırlayın</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Şifrəni unutmusunuz?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfən, 1 dəqiqə sonra cəhd edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Şifrəni sıfırlayın</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Şifrəni unutmusunuz?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PİN kod səhvdir`</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey tələb olunur</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PİN kodunuzu daxil edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfən %n dəqiqə(lər) sonra cəhd edin</numerusform><numerusform>Lütfən %n dəqiqə(lər) sonra cəhd edin</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfən, 1 dəqiqə sonra cəhd edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>İstifadəçi hesabı</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Şifrənizin vaxtı %n gün sonra bitəcəkdir, lütfən onu vaxtında dəyişin</numerusform><numerusform>Şifrənizin vaxtı %n gün sonra bitəcəkdir, lütfən onu vaxtında dəyişin</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Şifrənin vaxtı bitib, lütfən onu dəyişin</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Yalnış hesab</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Şifrə</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Ekranı kilidləmək</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ekran kilidlənə bilmədi</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Barmaq izi doğrulanması vaxtı bitdi, şifrəni əl ilə daxil edin</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Barmaq izi eyniləşdirilə bilmədi</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Yuxarıdakı istifadəçilər hələ də sistemdədilər və kompyuter söndürülərsə məlumatlar itiriləcək, söndürmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Yuxarıdakı istifadəçilər hələ də sistemdədilər və kompyuter yenidən başladılarsa məlumatlar itiriləcək, yenidən başlatmaq istədiyinizə əminsiniz?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Sisteminiz aktiv edilmiş yüksək təhlükəsizlik səviyyəsindədir, buna görə də Wayland rejiminə keçmək mümkün deyil. Lütfən Təhlükəsizlik Mərkəzində təhlükəsizlik səviyyəsini söndürün və yenidən cəhd edin.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Sistemi söndür</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlatmaq</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözlət</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilidləmək</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>İstifadıçini dəyişmək</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Başqa sistemə keçid</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Sistem İzləyicisini başlatmaq</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Bu tətbiq komputerin sönməsini əngəlləyir və məcburi söndürmə məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Tətbiqi bağlamaq üçün İmtina vurun və tətbiqi bağlayın</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Bu tətbiq komputerin yenidən başlanmasını əngəlləyir və məcburi yenidən başlatma, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Bu tətbiq komputerin dayandırılmasını əngəlləyir və məcburi dayandırılma, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Bu tətbiq komputerin yuxu rejiminə keçməsini əngəlləyir və məcburi yuxu rejiminə keçmə, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Bu tətbiq komputerin sistemdən çıxmasını əngəlləyir və sistemdən məcburi çıxış, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Söndürün</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başladın</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözləmə rejimi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Söndürmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Yenidən başlatmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sistemdən çıxmaq istədiyinizə əminsiniz?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Söndürmək</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.86.orig.tar.xz: dde-session-shell-5.5.86/translations/dde-session-shell_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Face İD-nizi doğrulayın</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face İD kilidləndi, lütfən şifrədən istifadə edin</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Cihaz əlçatmazdır</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Barmaq izinizi doğrulayın</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Barmaq izi kilidləndi, şifrədən istifadə edin</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Iris ID-nizi doğrulayın</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>İris İD kilidləndi, lütfən şifrədən istifadə edin</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Şifrə</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Şifrə</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfən, 1 dəqiqə sonra cəhd edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Şifrəni sıfırlayın</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Şifrəni unutmusunuz?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfən, 1 dəqiqə sonra cəhd edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform><numerusform>Lütfən %n dəqiqə sonra cəhd edin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Şifrəni sıfırlayın</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Şifrəni unutmusunuz?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Doğrulama uğurlu oldu</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform><numerusform>Doğrulama alınmadı, %n cəhdiniz qaldı</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Doğrulama alınmadı, yalnız bir cəhd qaldı</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PİN kod səhvdir`</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey tələb olunur</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PİN kodunuzu daxil edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Lütfən %n dəqiqə(lər) sonra cəhd edin</numerusform><numerusform>Lütfən %n dəqiqə(lər) sonra cəhd edin</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Lütfən, 1 dəqiqə sonra cəhd edin</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>İstifadəçi hesabı</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Şifrənin vaxtı bitib, lütfən onu dəyişin</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Yalnış hesab</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Yanlış Şifrə</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Ekranı kilidləmək</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Ekran kilidlənə bilmədi</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Barmaq izi doğrulanması vaxtı bitdi, şifrəni əl ilə daxil edin</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Barmaq izi eyniləşdirilə bilmədi</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>İmtina</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Yuxarıdakı istifadəçilər hələ də sistemdədilər və kompyuter söndürülərsə məlumatlar itiriləcək, söndürmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Yuxarıdakı istifadəçilər hələ də sistemdədilər və kompyuter yenidən başladılarsa məlumatlar itiriləcək, yenidən başlatmaq istədiyinizə əminsiniz?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Sisteminiz aktiv edilmiş yüksək təhlükəsizlik səviyyəsindədir, buna görə də Wayland rejiminə keçmək mümkün deyil. Lütfən Təhlükəsizlik Mərkəzində təhlükəsizlik səviyyəsini söndürün və yenidən cəhd edin.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Sistemi söndür</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başlatmaq</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözlət</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Kilidləmək</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>İstifadıçini dəyişmək</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Başqa sistemə keçid</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Sistem İzləyicisini başlatmaq</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Bu tətbiq komputerin sönməsini əngəlləyir və məcburi söndürmə məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Tətbiqi bağlamaq üçün İmtina vurun və tətbiqi bağlayın</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Bu tətbiq komputerin yenidən başlanmasını əngəlləyir və məcburi yenidən başlatma, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Bu tətbiq komputerin dayandırılmasını əngəlləyir və məcburi dayandırılma, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Bu tətbiq komputerin yuxu rejiminə keçməsini əngəlləyir və məcburi yuxu rejiminə keçmə, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Bu tətbiq komputerin sistemdən çıxmasını əngəlləyir və sistemdən məcburi çıxış, məlumatların itirilməsinə səbəb ola bilər.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Söndürün</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Yenidən başladın</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Gözləmə rejimi</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Yuxu rejimi</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Söndürmək istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Yenidən başlatmaq istədiyinizə əminsiniz?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sistemdən çıxmaq istədiyinizə əminsiniz?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Açmaq</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Söndürmək</translation>
    </message>
</context>
</TS>
